@@ -59,6 +59,11 @@ class Renderer(base.Renderer):
         self.project = self._get_project()
         self.project_url = self.project and self.project.absolute_url() or None
 
+    @property
+    def available(self):
+        """Determine if the portlet is available at all."""
+        return self.my_projects() 
+
     def _get_project(self):
         """This property return the url of the current project, if not within
         a project it return portal_url
@@ -84,17 +89,16 @@ class Renderer(base.Renderer):
 
         """
         results = []
-        tracker = self.tracker_url()
-        attachments = self.attachments_url()
-        offers = self.offers_url()
-        if tracker:
-            results.append(dict(url=tracker, title=_(u'Issues')))
-        if attachments:
-            results.append(dict(url=attachments, title=_(u'Attachments')))
-        if offers:
-            results.append(dict(url=offers, title=_(u'Offer')))
-        if results == []:
-            return None
+	if self.project:
+            tracker = self.tracker_url()
+            attachments = self.attachments_url()
+            offers = self.offers_url()
+            if tracker:
+                results.append(dict(url=tracker, title=_(u'Issues')))
+            if attachments:
+                results.append(dict(url=attachments, title=_(u'Attachments')))
+            if offers:
+                results.append(dict(url=offers, title=_(u'Offer')))
         for res in results:
             row = (results.index(res)+1)%2 and 'odd' or 'even'
             res['class'] = 'portletItem ' + row
@@ -108,7 +112,7 @@ class Renderer(base.Renderer):
         projects = []
         for pbrain in pbrains:
             projects.append(dict(title = pbrain.Title,
-                                 url = pbrain.getURL(),
+                                 url = pbrain.getURL,
                                  description = pbrain.Description))
         return projects
 
@@ -117,41 +121,38 @@ class Renderer(base.Renderer):
         if len(self.my_projects()) > 1:
             return True
         return False
-    
+
     @memoize
     def has_single_project(self):
         if len(self.my_projects()) == 1:
             return True
         return False
-        
+
     @memoize
     def tracker_url(self):
         """Return the url to the tracker, if available.
+	We expect this call only occurs when self.project is not None
         """
-        if self.project is None:
-            return None
         if 'issues' in self.project.objectIds():
             return self.project_url + '/issues'
 
     @memoize
     def attachments_url(self):
         """Return the url to the attachments view, if available.
+	We expect this call only occurs when self.project is not None
         """
-        if self.project is None:
-            return None
         cfilter = {'portal_type': ('File', 'Image')}
         brains = self.project.getFolderContents(cfilter)
         if brains and len(brains) > 0:
             return self.project_url + '/project_content?type=other'
         return None
-        
+
     @memoize
     def offers_url(self):
         """ Return the url to the offer, if available
+	We expect this call only occurs when self.project is not None
         """
-        if self.project is None:
-            return None
-        cfilter = {'portal_type': ('Offer',)}
+        cfilter = {'portal_type': ('Offer', )}
         brains = self.project.getFolderContents(cfilter)
         if brains and len(brains) == 1:
             return brains[0].getURL
